Τι είναι το OiRA; | OiRA

Θέματα

# Τι είναι το OiRA;

## Πρόκειται για την πρώτη επαφή σας με το εργαλείο OiRA;

Ακολουθεί μια σύντομη εισαγωγή στην εκτίμηση των κινδύνων και στη βοήθεια που μπορεί να σας παράσχει το OiRA για τη διαχείρισή τους.

## Τι είναι η εκτίμηση των κινδύνων;

Η εκτίμηση των κινδύνων είναι η βάση για την επιτυχή διαχείριση της ασφάλειας και της υγείας και το κλειδί για τη μείωση των εργατικών ατυχημάτων και των επαγγελματικών ασθενειών. Εάν εφαρμοστεί με τον κατάλληλο τρόπο, μπορεί να βελτιώσει την ασφάλεια και την υγεία στον χώρο εργασίας, καθώς και τις εν γένει επιδόσεις των επιχειρήσεων.

Στην Ευρώπη η ασφάλεια και η υγεία των εργαζομένων προστατεύονται μέσω της εκτίμησης και της διαχείρισης των κινδύνων στην εργασία. Οι εργοδότες υπέχουν τη νομική υποχρέωση να διασφαλίζουν την ασφάλεια και την υγεία των εργαζομένων σε κάθε πτυχή που σχετίζεται με την εργασία και να διεξάγουν εκτίμηση των κινδύνων. Ως εκ τούτου, κάθε επιχείρηση πρέπει να διεξάγει εκτίμηση των κινδύνων και να καταρτίζει σχέδιο δράσης. Προϋπόθεση για τη διεξαγωγή μιας αποτελεσματικής εκτίμησης των κινδύνων στον χώρο εργασίας είναι όλοι οι συμμετέχοντες σε αυτήν να αντιλαμβάνονται σαφώς:

- το νομικό πλαίσιο και τις σχετικές έννοιες,
- τη διαδικασία που εφαρμόζεται για την εκτίμηση των κινδύνων,
- τον ρόλο που διαδραματίζουν οι βασικοί παράγοντες που συμμετέχουν στη διαδικασία.

Οι εργαζόμενοι ή/και οι εκπρόσωποί τους έχουν δικαίωμα συμμετοχής στις διαβουλεύσεις σχετικά με τις εφαρμοστέες ρυθμίσεις και δικαίωμα συμμετοχής στην εκτίμηση των κινδύνων.

Περισσότερες πληροφορίες σχετικά με τη διαχείριση των κινδύνων και τη συμμετοχή των εργαζομένων ή/και των εκπροσώπων τους στη διαδικασία εκτίμησης των κινδύνων μπορείτε να βρείτε στον διαδικτυακό τόπο του έργου OiRA.

## Τι είναι το OiRA;

Το OiRA είναι ένα διαδικτυακό, διαδραστικό εργαλείο εκτίμησης των κινδύνων. Πρόκειται για διαδικτυακή εφαρμογή που σας επιτρέπει να εκπονείτε εκτιμήσεις των κινδύνων για την ασφάλεια και την υγεία στον χώρο εργασίας σας.

## Για ποιους προορίζεται το OiRA;

Το OiRA μπορεί να χρησιμοποιηθεί από οποιονδήποτε για την εκτίμηση κινδύνων σχετικών με την ασφάλεια και την υγεία που ενδεχομένως ελλοχεύουν στον χώρο εργασίας του.

Ωστόσο, το εργαλείο OiRA έχει σχεδιαστεί ώστε να είναι πιο επωφελές για τις μικρότερες επιχειρήσεις. Το OiRA έχει αναπτυχθεί για να τους προσφέρει εξειδικευμένη στήριξη στην εκτίμηση των κινδύνων που σχετίζονται με την εργασία και να τις βοηθά στην εκπόνηση τεκμηριωμένης εκτίμησης κινδύνων, όπου περιλαμβάνεται σχέδιο δράσης προσαρμοσμένο στις ανάγκες κάθε επιχείρησης.

## Τι πρέπει να κάνω;

Υπάρχουν αρκετά στάδια για την ολοκλήρωση της διαδικασίας εκτίμησης των κινδύνων με χρήση του εργαλείου OiRA:

- Προετοιμασία: ορισμένα εργαλεία περιέχουν ερωτήσεις σχετικές με το προφίλ της επιχείρησής σας οι οποίες σας βοηθούν να προσαρμόσετε το εργαλείο στα ειδικά χαρακτηριστικά της. Όταν απαντήσετε στις ερωτήσεις που αφορούν το προφίλ της επιχείρησής σας, το εργαλείο θα προσαρμοστεί στη συγκεκριμένη κατάστασή σας και θα σας δείξει τις ενότητες που ισχύουν.

- Συμμετοχή: κάθε εκτίμηση των κινδύνων πρέπει να διεξάγεται με την ενεργό συμμετοχή των εργαζομένων. Το εργαλείο σάς επιτρέπει να εκτυπώσετε το πλήρες κείμενο της εκτίμησης των κινδύνων ή μέρη αυτής για να ενημερώσετε τους εργαζόμενους και να λάβετε τις παρατηρήσεις τους.

- Αναγνώριση κινδύνων: Το OiRA θα παρουσιάσει μια σειρά από δυνητικούς κινδύνους για την ασφάλεια και την υγεία ή προβλήματα που θα μπορούσαν να προκύψουν στον χώρο εργασίας σας. Απαντώντας με ναι ή όχι στις δηλώσεις/ερωτήσεις που σας παρουσιάζονται, δηλώνετε εάν υφίστανται τέτοιου είδους κίνδυνοι ή προβλήματα στην επιχείρησή σας. Έχετε επίσης τη δυνατότητα να αποφασίσετε να παρακάμψετε μια ερώτηση, αναβάλλοντας την απάντησή σας για κάποια άλλη χρονική στιγμή.

- Αξιολόγηση: ορισμένα εργαλεία σας ζητούν να παρουσιάσετε με σειρά προτεραιότητας τους κινδύνους που έχετε αναγνωρίσει. Υπάρχουν διάφοροι τρόποι για να το επιχειρήσετε, ανάλογα με τις αποφάσεις των εθνικών μας εταίρων/των υπεύθυνων ανάπτυξης του εργαλείου OiRA και την εκάστοτε προσέγγισή τους. Επίσης, ορισμένα εργαλεία παρουσιάζουν αυτόματα τους κινδύνους κατά σειρά προτεραιότητας, την οποία έχετε τη δυνατότητα να απορρίψετε.

- Σχέδιο δράσης: για κάθε αναγνωρισμένο κίνδυνο, το εργαλείο σάς καλεί να αποφασίσετε για ένα ή περισσότερα μέτρα για την εξάλειψη ή τη μείωση του κινδύνου. Τα περισσότερα εργαλεία θα σας προτείνουν κάποια μέτρα. Μπορείτε επίσης σε κάθε περίπτωση να επιλέξετε να εισαγάγετε τα δικά σας μέτρα.

- Έκθεση: υπέχετε τη νομική υποχρέωση να τεκμηριώσετε την εκτίμηση των κινδύνων που έχετε εκπονήσει. Στην ενότητα που αφορά την έκθεση θα βρείτε ποικίλες εκθέσεις, οι οποίες θα σας βοηθήσουν να παρακολουθείτε την εκτίμηση των κινδύνων που έχετε εκπονήσει, καθώς και τις δράσεις/τα μέτρα που έχετε αποφασίσει να εφαρμόσετε για την εξάλειψη ή τη μείωση των αναγνωρισμένων κινδύνων.

## Πόσος χρόνος θα χρειαστεί;

Δεν είναι δυνατόν να πει κανείς πόσο χρόνο θα χρειαστείτε εν γένει για την εκπόνηση της εκτίμησης κινδύνου, καθώς τα εργαλεία διαφέρουν ανάλογα με τον κλάδο οικονομικής δραστηριότητας και τη χώρα.

Ωστόσο, έχετε τη δυνατότητα να αφιερώσετε όσο χρόνο χρειάζεστε για την εκπόνηση μιας εκτίμησης και στη συνέχεια να επιστρέψετε σε αυτήν οποιαδήποτε άλλη στιγμή το θελήσετε στο μέλλον, συνεχίζοντας από το σημείο όπου σταματήσατε.

## Γιατί πρέπει να εγγραφώ;

Η πρώτη ενέργεια που θα σας ζητηθεί να κάνετε όταν ξεκινήσετε την πρώτη σας εκτίμηση κινδύνου είναι να δημιουργήσετε έναν λογαριασμό OiRA –πρόκειται για μια απλή και σύντομη διαδικασία.

Η εγγραφή σάς επιτρέπει να συνδέεστε απλά ανά πάσα στιγμή για να συνεχίσετε προηγούμενες εκτιμήσεις ή να ξεκινήσετε νέες.

Εάν είστε εγγεγραμμένος χρήστης, μπορείτε επίσης ανά πάσα στιγμή να έχετε στη διάθεσή σας τυπωμένη, ακριβή και επικαιροποιημένη τη μελέτη εκτίμησης κινδύνου.

## Χρειάζεται ειδική προετοιμασία;

Δεν χρειάζεστε καμία ειδική προετοιμασία για να αρχίσετε να χρησιμοποιείτε το εργαλείο. Ωστόσο, πρέπει να αφιερώσετε λίγο χρόνο για να σκεφθείτε ποιος είναι αρμόδιος να εκπονήσει τη μελέτη εκτίμησης κινδύνου και πόσοι εργαζόμενοι θα συμμετάσχουν στη διαδικασία.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More